using System;
using System.Collections.Generic;
using System.Text;
using javax.naming;
using javax.rmi;
using java.util;
using com.ibm.websphere.samples.technologysamples.ejb.stateless.basiccalculatorejb;

namespace WebSphere6Example
{
    class Program
    {
        static string url;
        static string hostName = "";     // edit host name or IP address
        static string portNumber = "";  // edit with valid WebSphere bootstrap port, usually '2809'
        static string login = "";            // edit with a login, if required by WebSphere implementation
        static string passWord = "";     // edit with pass wprd, if required by WebSphere implementation     

        static void Main(string[] args)
        {
            BasicCalculatorHome basicCalculatorHome = null;

			// get the context
			// get the calculator home interface
			try
			{
				System.Console.WriteLine("JNDI stuff...");
                basicCalculatorHome = lookupHome();
				System.Console.WriteLine("Got home object");
			}
			catch( NamingException e )
			{
				System.Console.WriteLine("NamingException: " + e);
				return;
			}
			catch( java.lang.Exception e2 )
			{
				System.Console.WriteLine("Generic exception: " + e2);
				return;
			}

			// create the remote interface
			BasicCalculator basicCalculator = null;
			try
			{
				basicCalculator = basicCalculatorHome.create();
				Console.WriteLine("got remote interface");
			}
			catch ( javax.ejb.CreateException e1)
			{
				Console.WriteLine("CreateException: " + e1);
				return;
			}
			catch( java.lang.Exception e2 )
			{
				Console.WriteLine("Generic exception: " + e2);
				return;
			}

			// do some calculations
			try
			{
				double arg1 = 2.5;
				double arg2 = 3.9;
				double result;

				result = basicCalculator.makeSum(arg1, arg2);
				Console.WriteLine("{0} + {1} = {2}", arg1, arg2, result);
				result = basicCalculator.makeDifference(arg1, arg2);
				Console.WriteLine("{0} - {1} = {2}", arg1, arg2, result);
				result = basicCalculator.makeProduct(arg1, arg2);
				Console.WriteLine("{0} * {1} = {2}", arg1, arg2, result);
				result = basicCalculator.makeQuotient(arg1, arg2);
				Console.WriteLine("{0} / {1} = {2}", arg1, arg2, result);
			}
			catch(java.lang.Exception ex)
			{
				Console.WriteLine("Generic exception in calculation: " + ex);
				return;
			}
        }

        private static BasicCalculatorHome lookupHome()
        {
            Context ctx = getInitialContext();
            try
            {
                java.lang.Object home = ctx.lookup("WSsamples/BasicCalculator");
                return (BasicCalculatorHome)PortableRemoteObject.narrow(home
                    , java.lang.Class.forName("com.ibm.websphere.samples.technologysamples.ejb.stateless.basiccalculatorejb.BasicCalculatorHome"));

            }
            catch ( NamingException ne )
            {
                Console.WriteLine("The client was unable to lookup the EJBHome.  Please make sure " +
                "that you have deployed the ejb with the JNDI name " +
                "BasicCalculatorHome on the WebSphere server at " + url);
                throw ne;
            }
        }


        private static Context getInitialContext()
        {
            url = "iiop://" + hostName + ":" + portNumber;
            try
            {
                Properties h = new Properties();
                h.put((java.lang.JavaString)ContextConstants.INITIAL_CONTEXT_FACTORY
                    , (java.lang.JavaString)"com.ibm.websphere.naming.WsnInitialContextFactory");

                h.put((java.lang.JavaString)ContextConstants.PROVIDER_URL
                    , (java.lang.JavaString)url);

                if ( !string.IsNullOrEmpty(login) )
                {
                    h.put((java.lang.JavaString)ContextConstants.SECURITY_AUTHENTICATION
                        , (java.lang.JavaString)"simple");
                    h.put(new java.lang.JavaString(ContextConstants.SECURITY_PRINCIPAL)
                        , (java.lang.JavaString)login);
                    h.put(new java.lang.JavaString(ContextConstants.SECURITY_CREDENTIALS)
                        , (java.lang.JavaString)passWord);
                }

                // if the IBM JRE is being used, then comment out this line.
                // Also, remove 'sibc.orb.jar' from the 'classpath' attribute in the app.config file.
                h.put((java.lang.JavaString)"com.ibm.CORBA.ORBInit", (java.lang.JavaString)"com.ibm.ws.sib.client.ORB"); 




                return new InitialContext(h);

            }
            catch ( NamingException ne )
            {
                Console.WriteLine("We were unable to get a connection to the WebLogic server at " + url);
                Console.WriteLine("Please make sure that the server is running.");
                throw ne;
            }
        }

    }
}
